@@ -1,6 +1,6 @@
 package Reddit::Client;
 
-our $VERSION = '1.01';
+our $VERSION = '1.04';
 $VERSION = eval $VERSION;
 
 use strict;
@@ -176,6 +176,11 @@ sub new {
     return $self;
 }
 
+sub version {
+	my $self = shift;
+	return $VERSION;
+}
+
 #===============================================================================
 # Internal management
 #===============================================================================
@@ -420,11 +425,6 @@ sub list_subreddits {
     DEBUG('List subreddits [%s]', $type);
     defined $type || croak 'Expected $type"';
 
-    $self->require_login
-        if $type eq SUBREDDITS_MOD
-        || $type eq SUBREDDITS_MINE
-        || $type eq SUBREDDITS_CONTRIB;
-
     my $result = $self->api_json_request(api => API_SUBREDDITS, args => [$type]);
     return {
         map { $_->{data}{display_name} => Reddit::Client::SubReddit->new($self, $_->{data}) }
@@ -489,11 +489,15 @@ sub fetch_links {
     DEBUG('Fetch %d link(s): %s/%s?before=%s&after=%s', $limit, $subreddit, $view, ($before || '-'), ($after || '-'));
 
     my $query  = {};
-    if ($before || $after || $limit) { # limit is always defined
-        $query->{limit}  = $limit  if defined $limit;
+    if ($before || $after) { 
         $query->{before} = $before if defined $before;
         $query->{after}  = $after  if defined $after;
     }
+	if (exists $param{limit}) {
+		$query->{limit} = $param{limit} || 500;
+	} else {
+		$query->{limit} = DEFAULT_LIMIT;
+	}
 
     $subreddit = subreddit($subreddit);
 
@@ -506,11 +510,16 @@ sub fetch_links {
         data     => $query,
     );
 
-    return {
-        before => $result->{data}{before},
-        after  => $result->{data}{after},
-        items  => [ map {Reddit::Client::Link->new($self, $_->{data})} @{$result->{data}{children}} ],
-    };
+	# return before and after as a query property instead
+	# this will break EVERYTHING
+
+	# query => {
+        #	before => $result->{data}{before},
+        #	after  => $result->{data}{after},
+	# }
+    return [
+        map {Reddit::Client::Link->new($self, $_->{data})} @{$result->{data}{children}} 
+    ];
 }
 
 sub get_subreddit_comments {
@@ -529,7 +538,7 @@ sub get_subreddit_comments {
 	if (exists $param{limit}) {
 		$query->{limit} = $param{limit} || 500;
 	} else {
-		$query->{limit} = 25;
+		$query->{limit} = DEFAULT_LIMIT;
 	}
 
 	$subreddit = subreddit($subreddit); # remove slashes and leading r/
@@ -544,11 +553,12 @@ sub get_subreddit_comments {
 	#use Data::Dump::Color;
 	#dd $result;
 
-    	return {
-        	before => $result->{data}{before},
-        	after  => $result->{data}{after},
-        	items  => [ map {Reddit::Client::Comment->new($self, $_->{data})} @{$result->{data}{children}} ],
-    	};
+        	#before => $result->{data}{before},
+        	#after  => $result->{data}{after},
+		#items => []
+    	return [
+        	 map {Reddit::Client::Comment->new($self, $_->{data})} @{$result->{data}{children}} 
+    	];
 }
 
 #===============================================================================
@@ -727,7 +737,7 @@ __END__
 
 =head1 NAME
 
-Reddit::Client - A Perl wrapper for the Reddit API
+Reddit::Client - A Perl wrapper for the Reddit API.
 
 =head1 SYNOPSIS
 
@@ -735,8 +745,8 @@ Reddit::Client - A Perl wrapper for the Reddit API
 
     my $client_id  = "DFhtrhBgfhhRTd";
     my $secret     = "KrDNsbeffdbILOdgbgSvSBsbfFs";
-    my $username   = "reddit-username";
-    my $password   = "reddit-password";
+    my $username   = "reddit_username";
+    my $password   = "reddit_password";
 
 
     # Create a Reddit::Client object and authorize in one step
@@ -748,8 +758,8 @@ Reddit::Client - A Perl wrapper for the Reddit API
 	password	=> $password,
     );
 	
-    # Or create object then authenticate. 
-    # Useful if you need to authenticate more than once, for example if you were to check the inboxes of several accounts
+    # Or create object then authorize.
+    # Useful if you need to switch between accounts, for example if you were to check the inboxes of several accounts.
     my $reddit       = Reddit::Client->new(
         user_agent   => 'MyApp/1.0',
     );
@@ -761,24 +771,52 @@ Reddit::Client - A Perl wrapper for the Reddit API
 	password	=> $password,
     );
 
+    # Check your inbox
+    my $me = $reddit->me();
+    print "You've got mail!" if $me->{has_mail};
 
+    # Submit a link
     $reddit->submit_link(
-        subreddit => 'perl',
-        title     => 'Perl is still alive!',
-        url       => 'http://www.perl.org'
+        subreddit 	=> 'test',
+        title     	=> 'Perl is still alive!',
+        url       	=> 'http://www.perl.org'
     );
 
-    my $links = $reddit->fetch_links(subreddit => '/r/perl', limit => 10);
-    foreach (@{$links->{items}}) {
-        ...
+    # Submit a text post
+    $reddit->submit_text(
+	subreddit 	=> 'test',
+	title		=> 'my test',
+	text		=> 'a test'
+    );
+
+    # Get posts from a subreddit or multi
+    my $posts = $reddit->fetch_links(subreddit=>'test', limit=>5);
+    foreach my $post (@$posts) {
+	print $post->{title} . "\n";
+	if (!$post->{is_self}) { # Is it a self post or a link?
+		print $post->{url};
+	} else {
+		print $post->{selftext};
+	}
     }
 
+    # Get comments from a subreddit or multi
+    my $cmts = $reddit->get_subreddit_comments('test');
+    foreach my $cmt (@$cmts) {
+	print "$cmt->{author} says: $cmt->{body}\n";
+    }
+
+
 =head1 DESCRIPTION
 
 Reddit::Client provides methods and object wrappers for objects exposed
-by the Reddit API. This module handles HTTP communication, oauth session management, and communication with Reddit's external API.
+by the Reddit API. This module handles HTTP communication, oauth session management, and communication with Reddit's external API. For more information about the Reddit API, see L<https://github.com/reddit/reddit/wiki/API>.
 
-For more information about the Reddit API, see L<https://github.com/reddit/reddit/wiki/API>.
+Beginning August 3rd, 2015, the Reddit API requires Oauth authentication. This amounts to two extra arguments at the beginning of your script; in exchange you you twice as many requests per minute as before (60 vs 30) and some added convenience on the back end.
+
+To get Oauth keys, visit your apps page: L<https://www.reddit.com/prefs/apps>. Choose a "script" type app. None of the other fields are needed for a script type app; you can put in C<127.0.0.1> for the URLs or whatever you like.
+
+Every account that uses this script must have permission to use it. So for example if you were to check the inboxes of your various accounts, each one would need permission. To add accounts click "add developer" on the right, after you've created the app.
 
 =head1 CONSTANTS
 
@@ -818,7 +856,7 @@ When set to true, outputs a small amount of debugging information.
 
 =over
 
-=item new(user_agent => , [client_id =>, secret =>, username=>, password =>])
+=item new(user_agent => ... [, client_id =>, secret =>, username=>, password =>])
 
 Creates a new Reddit::Client object. Optionally authenticates at the same time. If any of the four optional arguments are used, all are required.
 
@@ -829,39 +867,31 @@ Get an Oauth token from Reddit. The client ID and secret come  from your apps pa
 
 For a Perl script, select a "script" type app. The "about url" and "redirect uri" can be any address; they are not used for scripts. 
 
-
-=item authorize()
-
-Alias for get_token().
-
-
-=item has_token()
+ 
+=item has_token
 
 Return true if a valid Oauth token exists.
 
 
-=item authorized()
-
-Alias for has_token().
-
-
-=item me()
+=item me
 
 Returns a Reddit::Client::Account object.
 
 
-=item info($item_id)
+=item info($fullname)
 
-Returns a has of information about C<$item_id>, which must be a complete name
-(e.g., t3_xxxxx).
+Returns a hash of information about C<$item_id>, which must be a fullname
+(i.e. the combination of a thing's ID and its prefix: "t3_xxxxx". A list of prefixes can be found at L<https://www.reddit.com/dev/api>). 
 
 
 =item list_subreddits($type)
 
 Returns a list of Reddit::Client::SubReddit objects for C<$type>, where C<$type>
-is a C<SUBREDDITS_*> constant.
+is a C<SUBREDDITS_*> constant. A number of alias functions are available:
 
 
+=over 4
+
 =item my_subreddits
 
 Syntactic sugar for C<list_subreddits(SUBREDDITS_MINE)>. 
@@ -891,7 +921,7 @@ Syntactic sugar for C<list_subreddits(SUBREDDITS_POPULAR)>.
 
 Syntactic sugar for C<list_subreddits(SUBREDDITS_NEW)>.
 
-
+=back
 
 
 =item find_subreddits($query)
@@ -901,7 +931,7 @@ Returns a list of SubReddit objects matching C<$query>.
 
 =item fetch_links([subreddit => ...], [view => ...], [limit => ...], [before => ...], [after => ...])
 
-Returns a list of links.
+Returns a list of Link objects. To get at the posts, iterate the C<items> array.
 
 All arguments are optional. If C<subreddit> is specified,
 the list of links is returned from the desired subreddit or multi (i.e. "pics+new"). Otherwise, the
@@ -914,7 +944,7 @@ as a hash with three keys, I<before>, I<after>, and I<items>.
 
 =item delete_item(name => ...)
 
-Deletes a post or comment. The object's full name is required.
+Deletes a post or comment. The object's fullname is required.
 
 
 =item submit_link(subreddit => ..., title => ..., url => ...)
@@ -934,35 +964,35 @@ Return a list of Reddit::Client::Comment objects from a subreddit or multi. All
 
 =item submit_comment(parent_id => ..., text => ...)
 
-Submits a new comment underneath C<parent_id>.
+Submits a new comment underneath C<parent_id>. C<parent_id> must be a fullname.
 
 
 =item vote(item_id => ..., direction => ...)
 
 Votes for C<item_id>. C<direction> is one of C<VOTE_UP>, C<VOTE_DOWN>,
-or C<VOTE_NONE>.
+or C<VOTE_NONE>. C<item_id> must be a fullname.
 
 
 =item save($item_id)
 
-Saves C<$item_id> under the user's account.
+Saves C<$item_id> under the user's account. C<item_id> must be a fullname.
 
 
 =item unsave($item_id)
 
-Unsaves C<$item_id> under the user's account.
+Unsaves C<$item_id> under the user's account. C<item_id> must be a fullname.
 
 
 =item hide($item_id)
 
 Hides $<item_id>. Throws an error if the user does not have permission to hide
-the item in question.
+the item in question. C<item_id> must be a fullname.
 
 
 =item unhide($item_id)
 
 Unhides $<item_id>. Throws an error if the user does not have permission to
-unhide the item in question.
+unhide the item in question. C<item_id> must be a fullname.
 
 
 =back
@@ -977,10 +1007,6 @@ When C<$Reddit::Client::DEBUG> is true, acts as syntactic sugar for
 warn(sprintf(@_)). Used to provided logging.
 
 
-=item require_login
-
-Throws an error if the user is not logged in. No longer used.
-
 
 =item subreddit
 
@@ -1012,9 +1038,8 @@ Wraps C<json_request>, getting method and path from an API_CONSTANT.
 
 =head1 AUTHOR
 
-<mailto:earth-tone@ubwg.net>
+L<mailto:earth-tone@ubwg.net>
 
-Jeff Ober L<mailto:jeffober@gmail.com>
 
 =head1 LICENSE
 
